# phone_com_client

PhoneComClient - the Ruby gem for the Phone.com API

This is a Phone.com api PhoneCom definition

This SDK is automatically generated by the [PhoneCom Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build phone_com_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./phone_com_client-1.0.0.gem
```
(for development, run `gem install --dev ./phone_com_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'phone_com_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO, then add the following in the Gemfile:

    gem 'phone_com_client', :git => 'https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'phone_com_client'

# Setup authorization
PhoneComClient.configure do |config|
  # Configure API key authorization: apiKey
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = PhoneComClient::AccountsApi.new

account_id = 56 # Integer | Account ID


begin
  #Retrieve details of an individual account
  result = api_instance.get_account(account_id, )
  p result
rescue PhoneComClient::ApiError => e
  puts "Exception when calling AccountsApi->get_account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.phone.com/v4*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PhoneComClient::AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /accounts/{account_id} | Retrieve details of an individual account
*PhoneComClient::AccountsApi* | [**list_accounts**](docs/AccountsApi.md#list_accounts) | **GET** /accounts | Get a list of accounts visible to the authenticated user or client.
*PhoneComClient::ApplicationsApi* | [**get_account_application**](docs/ApplicationsApi.md#get_account_application) | **GET** /accounts/{account_id}/applications/{application_id} | Show details of an individual Application on a given account.
*PhoneComClient::ApplicationsApi* | [**list_account_applications**](docs/ApplicationsApi.md#list_account_applications) | **GET** /accounts/{account_id}/applications | This service lists the Applications on a given account
*PhoneComClient::AvailableNumbersApi* | [**list_available_phone_numbers**](docs/AvailableNumbersApi.md#list_available_phone_numbers) | **GET** /phone-numbers/available |
*PhoneComClient::CallLogsApi* | [**get_account_call_logs**](docs/CallLogsApi.md#get_account_call_logs) | **GET** /accounts/{account_id}/call-logs/{call_id} | Show details of an individual Call Log entry
*PhoneComClient::CallLogsApi* | [**list_account_call_logs**](docs/CallLogsApi.md#list_account_call_logs) | **GET** /accounts/{account_id}/call-logs | Get a list of call details associated with your account
*PhoneComClient::CallerIdsApi* | [**get_caller_ids**](docs/CallerIdsApi.md#get_caller_ids) | **GET** /accounts/{account_id}/extensions/{extension_id}/caller-ids | Show the Caller ID options a given extension can use.
*PhoneComClient::CallsApi* | [**create_account_call**](docs/CallsApi.md#create_account_call) | **POST** /accounts/{account_id}/calls | Make a phone call
*PhoneComClient::ContactsApi* | [**create_account_extension_contact**](docs/ContactsApi.md#create_account_extension_contact) | **POST** /accounts/{account_id}/extensions/{extension_id}/contacts | Add a new address book contact for an extension.
*PhoneComClient::ContactsApi* | [**delete_account_extension_contact**](docs/ContactsApi.md#delete_account_extension_contact) | **DELETE** /accounts/{account_id}/extensions/{extension_id}/contacts/{contact_id} | Delete a contact from the address book.
*PhoneComClient::ContactsApi* | [**get_account_extension_contact**](docs/ContactsApi.md#get_account_extension_contact) | **GET** /accounts/{account_id}/extensions/{extension_id}/contacts/{contact_id} | Retrieve the details of an address book contact.
*PhoneComClient::ContactsApi* | [**list_account_extension_contacts**](docs/ContactsApi.md#list_account_extension_contacts) | **GET** /accounts/{account_id}/extensions/{extension_id}/contacts | Show the Caller ID options a given extension can use.
*PhoneComClient::ContactsApi* | [**replace_account_extension_contact**](docs/ContactsApi.md#replace_account_extension_contact) | **PUT** /accounts/{account_id}/extensions/{extension_id}/contacts/{contact_id} | Update the info of a contact in the address book.
*PhoneComClient::DefaultApi* | [**ping**](docs/DefaultApi.md#ping) | **GET** /ping | The default API command
*PhoneComClient::DevicesApi* | [**create_account_device**](docs/DevicesApi.md#create_account_device) | **POST** /accounts/{account_id}/devices | Register a generic VoIP device.
*PhoneComClient::DevicesApi* | [**delete_account_device**](docs/DevicesApi.md#delete_account_device) | **DELETE** /accounts/{account_id}/devices/{device_id} | Delete a VoIP device.
*PhoneComClient::DevicesApi* | [**get_account_device**](docs/DevicesApi.md#get_account_device) | **GET** /accounts/{account_id}/devices/{device_id} | Show details of an individual VoIP device.
*PhoneComClient::DevicesApi* | [**list_account_devices**](docs/DevicesApi.md#list_account_devices) | **GET** /accounts/{account_id}/devices | Get a list of VoIP devices associated with your account.
*PhoneComClient::DevicesApi* | [**replace_account_device**](docs/DevicesApi.md#replace_account_device) | **PUT** /accounts/{account_id}/devices/{device_id} | Update the details of an individual VoIP device.
*PhoneComClient::ExpressServiceCodesApi* | [**get_account_express_srv_code**](docs/ExpressServiceCodesApi.md#get_account_express_srv_code) | **GET** /accounts/{account_id}/express-service-codes/{code_id} | Show details of an account Express Service Code
*PhoneComClient::ExpressServiceCodesApi* | [**list_account_express_srv_codes**](docs/ExpressServiceCodesApi.md#list_account_express_srv_codes) | **GET** /accounts/{account_id}/express-service-codes | Get the Express Service Code associated with your account in list format.
*PhoneComClient::ExtensionsApi* | [**create_account_extension**](docs/ExtensionsApi.md#create_account_extension) | **POST** /accounts/{account_id}/extensions | Create an individual extension.
*PhoneComClient::ExtensionsApi* | [**get_account_extension**](docs/ExtensionsApi.md#get_account_extension) | **GET** /accounts/{account_id}/extensions/{extension_id} | Show details of an individual extension.
*PhoneComClient::ExtensionsApi* | [**list_account_extensions**](docs/ExtensionsApi.md#list_account_extensions) | **GET** /accounts/{account_id}/extensions | Get a list of extensions visible to the authenticated user or client.
*PhoneComClient::ExtensionsApi* | [**replace_account_extension**](docs/ExtensionsApi.md#replace_account_extension) | **PUT** /accounts/{account_id}/extensions/{extension_id} | Replace an individual extension.
*PhoneComClient::GroupsApi* | [**create_account_extension_contact_group**](docs/GroupsApi.md#create_account_extension_contact_group) | **POST** /accounts/{account_id}/extensions/{extension_id}/contact-groups | Add a new contact group to an account extension.
*PhoneComClient::GroupsApi* | [**delete_account_extension_contact_group**](docs/GroupsApi.md#delete_account_extension_contact_group) | **DELETE** /accounts/{account_id}/extensions/{extension_id}/contact-groups/{group_id} | Delete a contact group from the address book.
*PhoneComClient::GroupsApi* | [**get_account_extension_contact_group**](docs/GroupsApi.md#get_account_extension_contact_group) | **GET** /accounts/{account_id}/extensions/{extension_id}/contact-groups/{group_id} | Retrieve the information of a contact group.
*PhoneComClient::GroupsApi* | [**list_account_extension_contact_groups**](docs/GroupsApi.md#list_account_extension_contact_groups) | **GET** /accounts/{account_id}/extensions/{extension_id}/contact-groups | Show a list of contact groups belonging to an extension.
*PhoneComClient::GroupsApi* | [**replace_account_extension_contact_group**](docs/GroupsApi.md#replace_account_extension_contact_group) | **PUT** /accounts/{account_id}/extensions/{extension_id}/contact-groups/{group_id} | Update the information of a contact group.
*PhoneComClient::ListenersApi* | [**create_account_listener**](docs/ListenersApi.md#create_account_listener) | **POST** /accounts/{account_id}/listeners | Add a listener object to your account that can be used to subscribe an event.
*PhoneComClient::ListenersApi* | [**delete_account_listener**](docs/ListenersApi.md#delete_account_listener) | **DELETE** /accounts/{account_id}/listeners/{listener_id} | Delete an individual event listener.
*PhoneComClient::ListenersApi* | [**get_account_listener**](docs/ListenersApi.md#get_account_listener) | **GET** /accounts/{account_id}/listeners/{listener_id} | Show details of an individual listener.
*PhoneComClient::ListenersApi* | [**list_account_listeners**](docs/ListenersApi.md#list_account_listeners) | **GET** /accounts/{account_id}/listeners | Get a list of listeners for an account.
*PhoneComClient::ListenersApi* | [**replace_account_listener**](docs/ListenersApi.md#replace_account_listener) | **PUT** /accounts/{account_id}/listeners/{listener_id} | Update the settings of an individual event listener.
*PhoneComClient::MediaApi* | [**create_account_media_files**](docs/MediaApi.md#create_account_media_files) | **POST** /accounts/{account_id}/media/files | Add a media object to your account that can be used as a greeting or hold music. Users may create a media by using the built-in Text-to-speech (TTS) facility or upload a file of their choice. (Note: The maximum size for media files or JSON objects included with a POST or PUT request is 10 MB)
*PhoneComClient::MediaApi* | [**create_account_media_tts**](docs/MediaApi.md#create_account_media_tts) | **POST** /accounts/{account_id}/media/tts | Add a media object to your account that can be used as a greeting or hold music. Users may create a media by using the built-in Text-to-speech (TTS) facility or upload a file of their choice. (Note: The maximum size for media files or JSON objects included with a POST or PUT request is 10 MB)
*PhoneComClient::MediaApi* | [**delete_account_media**](docs/MediaApi.md#delete_account_media) | **DELETE** /accounts/{account_id}/media/{media_id} | Delete an individual media record
*PhoneComClient::MediaApi* | [**get_account_media**](docs/MediaApi.md#get_account_media) | **GET** /accounts/{account_id}/media/{media_id} | Show details of an individual media recording (Greeting or Hold Music)
*PhoneComClient::MediaApi* | [**list_account_media**](docs/MediaApi.md#list_account_media) | **GET** /accounts/{account_id}/media | Get a list of media recordings for an account.
*PhoneComClient::MediaApi* | [**replace_account_media_files**](docs/MediaApi.md#replace_account_media_files) | **PUT** /accounts/{account_id}/media/files/{media_id} | Update a media object to your account. Note: The maximum size for media files or JSON objects included with a POST or PUT request is 10 MB.
*PhoneComClient::MediaApi* | [**replace_account_media_tts**](docs/MediaApi.md#replace_account_media_tts) | **PUT** /accounts/{account_id}/media/tts/{media_id} | Update a media object to your account.
*PhoneComClient::MenusApi* | [**create_account_menu**](docs/MenusApi.md#create_account_menu) | **POST** /accounts/{account_id}/menus | Create an individual menu.
*PhoneComClient::MenusApi* | [**delete_account_menu**](docs/MenusApi.md#delete_account_menu) | **DELETE** /accounts/{account_id}/menus/{menu_id} | Delete an individual menu.
*PhoneComClient::MenusApi* | [**get_account_menu**](docs/MenusApi.md#get_account_menu) | **GET** /accounts/{account_id}/menus/{menu_id} | Show details of an individual menu.
*PhoneComClient::MenusApi* | [**list_account_menus**](docs/MenusApi.md#list_account_menus) | **GET** /accounts/{account_id}/menus | Get a list of menus for an account.
*PhoneComClient::MenusApi* | [**replace_account_menu**](docs/MenusApi.md#replace_account_menu) | **PUT** /accounts/{account_id}/menus/{menu_id} | Replace an individual menu.
*PhoneComClient::NumberRegionsApi* | [**list_available_phone_number_regions**](docs/NumberRegionsApi.md#list_available_phone_number_regions) | **GET** /phone-numbers/available/regions |
*PhoneComClient::OauthApi* | [**create_oauth_access_token**](docs/OauthApi.md#create_oauth_access_token) | **POST** /oauth/access-token | To create an access token via the /oauth/access-token API, an API user may choose any one of the grant types it supports: Authorization Code Grant, Client Credential Grant, Password Credential Grant or Refresh Token Grant.
*PhoneComClient::OauthApi* | [**create_oauth_authorization**](docs/OauthApi.md#create_oauth_authorization) | **GET** /oauth/authorization | Create Authorization Code or Access Token.
*PhoneComClient::OauthApi* | [**get_oauth_access_token**](docs/OauthApi.md#get_oauth_access_token) | **GET** /oauth/access-token | Retrieve details of an access token, such as scope, expiration and extension ID.
*PhoneComClient::OauthClientsApi* | [**delete_account_oauth_client**](docs/OauthClientsApi.md#delete_account_oauth_client) | **DELETE** /accounts/{account_id}/oauth/clients/{client_id} | Delete an individual OAuth client.
*PhoneComClient::OauthClientsApi* | [**get_account_oauth_client**](docs/OauthClientsApi.md#get_account_oauth_client) | **GET** /accounts/{account_id}/oauth/clients/{client_id} | Show details of an individual OAuth client.
*PhoneComClient::OauthClientsApi* | [**list_account_oauth_clients**](docs/OauthClientsApi.md#list_account_oauth_clients) | **GET** /accounts/{account_id}/oauth/clients | Get a list of OAuth clients for an account.
*PhoneComClient::OauthClientsRedirectUrisApi* | [**create_account_oauth_clients_redirect_uri**](docs/OauthClientsRedirectUrisApi.md#create_account_oauth_clients_redirect_uri) | **POST** /accounts/{account_id}/oauth/clients/{client_id}/redirect-uris | Create an OAuth Client Redirect URI record.
*PhoneComClient::OauthClientsRedirectUrisApi* | [**delete_account_oauth_clients_redirect_uri**](docs/OauthClientsRedirectUrisApi.md#delete_account_oauth_clients_redirect_uri) | **DELETE** /accounts/{account_id}/oauth/clients/{client_id}/redirect-uris/{uri_id} | Delete an OAuth Client Redirect URI record.
*PhoneComClient::OauthClientsRedirectUrisApi* | [**get_account_oauth_clients_redirect_uri**](docs/OauthClientsRedirectUrisApi.md#get_account_oauth_clients_redirect_uri) | **GET** /accounts/{account_id}/oauth/clients/{client_id}/redirect-uris/{uri_id} | Get details of an OAuth Client Redirect URI record.
*PhoneComClient::OauthClientsRedirectUrisApi* | [**list_account_oauth_clients_redirect_uris**](docs/OauthClientsRedirectUrisApi.md#list_account_oauth_clients_redirect_uris) | **GET** /accounts/{account_id}/oauth/clients/{client_id}/redirect-uris | Get a list of OAuth Client Redirect URIs for an account.
*PhoneComClient::PaymentMethodsApi* | [**create_account_payment_method**](docs/PaymentMethodsApi.md#create_account_payment_method) | **POST** /accounts/{account_id}/payment-methods | Create an individual payment method.
*PhoneComClient::PaymentMethodsApi* | [**delete_account_payment_method**](docs/PaymentMethodsApi.md#delete_account_payment_method) | **DELETE** /accounts/{account_id}/payment-methods/{pm_id} | Delete an individual payment method.
*PhoneComClient::PaymentMethodsApi* | [**get_account_payment_method**](docs/PaymentMethodsApi.md#get_account_payment_method) | **GET** /accounts/{account_id}/payment-methods/{pm_id} | Show details of an individual payment method.
*PhoneComClient::PaymentMethodsApi* | [**list_account_payment_methods**](docs/PaymentMethodsApi.md#list_account_payment_methods) | **GET** /accounts/{account_id}/payment-methods | Get a list of payment methods for an account.
*PhoneComClient::PaymentMethodsApi* | [**patch_account_payment_method**](docs/PaymentMethodsApi.md#patch_account_payment_method) | **PATCH** /accounts/{account_id}/payment-methods/{pm_id} | Replace the status of an individual payment method.
*PhoneComClient::PhoneNumbersApi* | [**create_account_phone_number**](docs/PhoneNumbersApi.md#create_account_phone_number) | **POST** /accounts/{account_id}/phone-numbers | Add a phone number to an account.
*PhoneComClient::PhoneNumbersApi* | [**get_account_phone_number**](docs/PhoneNumbersApi.md#get_account_phone_number) | **GET** /accounts/{account_id}/phone-numbers/{number_id} | Show details of an individual phone number.
*PhoneComClient::PhoneNumbersApi* | [**list_account_phone_numbers**](docs/PhoneNumbersApi.md#list_account_phone_numbers) | **GET** /accounts/{account_id}/phone-numbers | Get a list of phone numbers registered to an account.
*PhoneComClient::PhoneNumbersApi* | [**replace_account_phone_number**](docs/PhoneNumbersApi.md#replace_account_phone_number) | **PUT** /accounts/{account_id}/phone-numbers/{number_id} | Update the settings for an existing phone number on your account.
*PhoneComClient::QueuesApi* | [**create_account_queue**](docs/QueuesApi.md#create_account_queue) | **POST** /accounts/{account_id}/queues | Create a queue.
*PhoneComClient::QueuesApi* | [**delete_account_queue**](docs/QueuesApi.md#delete_account_queue) | **DELETE** /accounts/{account_id}/queues/{queue_id} | Delete a queue.
*PhoneComClient::QueuesApi* | [**get_account_queue**](docs/QueuesApi.md#get_account_queue) | **GET** /accounts/{account_id}/queues/{queue_id} | Show details of an individual queue.
*PhoneComClient::QueuesApi* | [**list_account_queues**](docs/QueuesApi.md#list_account_queues) | **GET** /accounts/{account_id}/queues | Get a list of queues for an account.
*PhoneComClient::QueuesApi* | [**replace_account_queue**](docs/QueuesApi.md#replace_account_queue) | **PUT** /accounts/{account_id}/queues/{queue_id} | Replace a queue.
*PhoneComClient::RoutesApi* | [**create_route**](docs/RoutesApi.md#create_route) | **POST** /accounts/{account_id}/routes | Add a new route to the account.
*PhoneComClient::RoutesApi* | [**delete_account_route**](docs/RoutesApi.md#delete_account_route) | **DELETE** /accounts/{account_id}/routes/{route_id} | Delete a route from the account.
*PhoneComClient::RoutesApi* | [**get_account_route**](docs/RoutesApi.md#get_account_route) | **GET** /accounts/{account_id}/routes/{route_id} | Show details of an individual route.
*PhoneComClient::RoutesApi* | [**list_account_routes**](docs/RoutesApi.md#list_account_routes) | **GET** /accounts/{account_id}/routes | Get a list of routes for an account.
*PhoneComClient::RoutesApi* | [**replace_account_route**](docs/RoutesApi.md#replace_account_route) | **PUT** /accounts/{account_id}/routes/{route_id} | Update the information of a route.
*PhoneComClient::SchedulesApi* | [**get_account_schedule**](docs/SchedulesApi.md#get_account_schedule) | **GET** /accounts/{account_id}/schedules/{schedule_id} | Show details of an individual schedule
*PhoneComClient::SchedulesApi* | [**list_account_schedules**](docs/SchedulesApi.md#list_account_schedules) | **GET** /accounts/{account_id}/schedules | Get a list of schedules for an account
*PhoneComClient::SmsApi* | [**create_account_sms**](docs/SmsApi.md#create_account_sms) | **POST** /accounts/{account_id}/sms | Send a SMS to one or a group of recipients.
*PhoneComClient::SmsApi* | [**get_account_sms**](docs/SmsApi.md#get_account_sms) | **GET** /accounts/{account_id}/sms/{sms_id} | This service shows the details of an individual SMS.
*PhoneComClient::SmsApi* | [**list_account_sms**](docs/SmsApi.md#list_account_sms) | **GET** /accounts/{account_id}/sms | Get a list of SMS messages for an account.
*PhoneComClient::SmsApi* | [**patch_account_sms**](docs/SmsApi.md#patch_account_sms) | **PATCH** /accounts/{account_id}/sms/{sms_id} | Update the is_new parameter in a sms record.
*PhoneComClient::SubaccountPricingApi* | [**create_account_subaccount_pricing**](docs/SubaccountPricingApi.md#create_account_subaccount_pricing) | **POST** /accounts/{account_id}/subaccounts/{subaccount_id}/pricing | Add a pricing plan to a subaccount.
*PhoneComClient::SubaccountPricingApi* | [**delete_account_subaccount_pricing**](docs/SubaccountPricingApi.md#delete_account_subaccount_pricing) | **DELETE** /accounts/{account_id}/subaccounts/{subaccount_id}/pricing/{pricing_id} | Delete a pricing plan from a subaccount.
*PhoneComClient::SubaccountPricingApi* | [**get_account_subaccount_pricing**](docs/SubaccountPricingApi.md#get_account_subaccount_pricing) | **GET** /accounts/{account_id}/subaccounts/{subaccount_id}/pricing/{pricing_id} | Get the details of a pricing plan for a subaccount.
*PhoneComClient::SubaccountPricingApi* | [**list_account_subaccount_pricing**](docs/SubaccountPricingApi.md#list_account_subaccount_pricing) | **GET** /accounts/{account_id}/subaccounts/{subaccount_id}/pricing | Get a list of pricing plans for a subaccount.
*PhoneComClient::SubaccountsApi* | [**create_account_subaccount**](docs/SubaccountsApi.md#create_account_subaccount) | **POST** /accounts/{account_id}/subaccounts | Add a subaccount for the authenticated user or client
*PhoneComClient::SubaccountsApi* | [**list_account_subaccounts**](docs/SubaccountsApi.md#list_account_subaccounts) | **GET** /accounts/{account_id}/subaccounts | Get a list of subaccounts for the authenticated user or client
*PhoneComClient::TrunksApi* | [**create_account_trunk**](docs/TrunksApi.md#create_account_trunk) | **POST** /accounts/{account_id}/trunks | Add a trunk record with SIP information.
*PhoneComClient::TrunksApi* | [**delete_account_trunk**](docs/TrunksApi.md#delete_account_trunk) | **DELETE** /accounts/{account_id}/trunks/{trunk_id} | Delete a trunk from account.
*PhoneComClient::TrunksApi* | [**get_account_trunk**](docs/TrunksApi.md#get_account_trunk) | **GET** /accounts/{account_id}/trunks/{trunk_id} | Show details of an individual trunk.
*PhoneComClient::TrunksApi* | [**list_account_trunks**](docs/TrunksApi.md#list_account_trunks) | **GET** /accounts/{account_id}/trunks | Get a list of trunks for an account.
*PhoneComClient::TrunksApi* | [**replace_account_trunk**](docs/TrunksApi.md#replace_account_trunk) | **PUT** /accounts/{account_id}/trunks/{trunk_id} | Replace parameters in a trunk.
*PhoneComClient::VoicemailApi* | [**get_account_voicemail**](docs/VoicemailApi.md#get_account_voicemail) | **GET** /accounts/{account_id}/voicemail/{voicemail_id} | This service shows the details of an individual voicemail.
*PhoneComClient::VoicemailApi* | [**list_account_voicemail**](docs/VoicemailApi.md#list_account_voicemail) | **GET** /accounts/{account_id}/voicemail | Get a list of voicemail messages for an account.
*PhoneComClient::VoicemailApi* | [**patch_account_voicemail**](docs/VoicemailApi.md#patch_account_voicemail) | **PATCH** /accounts/{account_id}/voicemail/{voicemail_id} | Update the is_new parameter in a voicemail record.


## Documentation for Models

 - [PhoneComClient::AccountFull](docs/AccountFull.md)
 - [PhoneComClient::AccountSummary](docs/AccountSummary.md)
 - [PhoneComClient::Address](docs/Address.md)
 - [PhoneComClient::AddressListContacts](docs/AddressListContacts.md)
 - [PhoneComClient::ApplicationFull](docs/ApplicationFull.md)
 - [PhoneComClient::ApplicationSummary](docs/ApplicationSummary.md)
 - [PhoneComClient::AvailableNumbersFull](docs/AvailableNumbersFull.md)
 - [PhoneComClient::CallDetails](docs/CallDetails.md)
 - [PhoneComClient::CallFull](docs/CallFull.md)
 - [PhoneComClient::CallLogFull](docs/CallLogFull.md)
 - [PhoneComClient::CallNotifications](docs/CallNotifications.md)
 - [PhoneComClient::CallbackObject](docs/CallbackObject.md)
 - [PhoneComClient::CallerIdFull](docs/CallerIdFull.md)
 - [PhoneComClient::CallerIdPhoneNumber](docs/CallerIdPhoneNumber.md)
 - [PhoneComClient::ContactAccount](docs/ContactAccount.md)
 - [PhoneComClient::ContactFull](docs/ContactFull.md)
 - [PhoneComClient::ContactResponse](docs/ContactResponse.md)
 - [PhoneComClient::ContactSummary](docs/ContactSummary.md)
 - [PhoneComClient::CreateCallParams](docs/CreateCallParams.md)
 - [PhoneComClient::CreateContactParams](docs/CreateContactParams.md)
 - [PhoneComClient::CreateDeviceParams](docs/CreateDeviceParams.md)
 - [PhoneComClient::CreateExtensionParams](docs/CreateExtensionParams.md)
 - [PhoneComClient::CreateGroupParams](docs/CreateGroupParams.md)
 - [PhoneComClient::CreateListenerParams](docs/CreateListenerParams.md)
 - [PhoneComClient::CreateMediaParams](docs/CreateMediaParams.md)
 - [PhoneComClient::CreateMenuParams](docs/CreateMenuParams.md)
 - [PhoneComClient::CreateOauthParams](docs/CreateOauthParams.md)
 - [PhoneComClient::CreatePaymentParams](docs/CreatePaymentParams.md)
 - [PhoneComClient::CreatePhoneNumberParams](docs/CreatePhoneNumberParams.md)
 - [PhoneComClient::CreatePricingParams](docs/CreatePricingParams.md)
 - [PhoneComClient::CreateQueueParams](docs/CreateQueueParams.md)
 - [PhoneComClient::CreateRedirectUriParams](docs/CreateRedirectUriParams.md)
 - [PhoneComClient::CreateRouteParams](docs/CreateRouteParams.md)
 - [PhoneComClient::CreateSmsParams](docs/CreateSmsParams.md)
 - [PhoneComClient::CreateSubaccountParams](docs/CreateSubaccountParams.md)
 - [PhoneComClient::CreateTrunkParams](docs/CreateTrunkParams.md)
 - [PhoneComClient::DeleteEntry](docs/DeleteEntry.md)
 - [PhoneComClient::DeviceFull](docs/DeviceFull.md)
 - [PhoneComClient::DeviceMembership](docs/DeviceMembership.md)
 - [PhoneComClient::DeviceSummary](docs/DeviceSummary.md)
 - [PhoneComClient::Email](docs/Email.md)
 - [PhoneComClient::ExpressServiceCodeFull](docs/ExpressServiceCodeFull.md)
 - [PhoneComClient::ExtensionFull](docs/ExtensionFull.md)
 - [PhoneComClient::ExtensionSummary](docs/ExtensionSummary.md)
 - [PhoneComClient::FilterCallLogs](docs/FilterCallLogs.md)
 - [PhoneComClient::FilterIdArray](docs/FilterIdArray.md)
 - [PhoneComClient::FilterIdDirectionFrom](docs/FilterIdDirectionFrom.md)
 - [PhoneComClient::FilterIdExtensionNameArray](docs/FilterIdExtensionNameArray.md)
 - [PhoneComClient::FilterIdGroupIdUpdatedAtArray](docs/FilterIdGroupIdUpdatedAtArray.md)
 - [PhoneComClient::FilterIdNameArray](docs/FilterIdNameArray.md)
 - [PhoneComClient::FilterIdNamePhoneNumberArray](docs/FilterIdNamePhoneNumberArray.md)
 - [PhoneComClient::FilterListAvailableNumbers](docs/FilterListAvailableNumbers.md)
 - [PhoneComClient::FilterListPhoneNumbersRegions](docs/FilterListPhoneNumbersRegions.md)
 - [PhoneComClient::FilterNameNumberArray](docs/FilterNameNumberArray.md)
 - [PhoneComClient::FilterVoicemailArray](docs/FilterVoicemailArray.md)
 - [PhoneComClient::FromObject](docs/FromObject.md)
 - [PhoneComClient::GetOauthAccessToken](docs/GetOauthAccessToken.md)
 - [PhoneComClient::Greeting](docs/Greeting.md)
 - [PhoneComClient::GreetingInput](docs/GreetingInput.md)
 - [PhoneComClient::GroupFull](docs/GroupFull.md)
 - [PhoneComClient::GroupListContacts](docs/GroupListContacts.md)
 - [PhoneComClient::GroupSummary](docs/GroupSummary.md)
 - [PhoneComClient::HoldMusic](docs/HoldMusic.md)
 - [PhoneComClient::Line](docs/Line.md)
 - [PhoneComClient::ListAccounts](docs/ListAccounts.md)
 - [PhoneComClient::ListApplications](docs/ListApplications.md)
 - [PhoneComClient::ListAvailableNumbers](docs/ListAvailableNumbers.md)
 - [PhoneComClient::ListCallLogs](docs/ListCallLogs.md)
 - [PhoneComClient::ListCallerIds](docs/ListCallerIds.md)
 - [PhoneComClient::ListContacts](docs/ListContacts.md)
 - [PhoneComClient::ListDevices](docs/ListDevices.md)
 - [PhoneComClient::ListExpressServiceCodes](docs/ListExpressServiceCodes.md)
 - [PhoneComClient::ListExtensions](docs/ListExtensions.md)
 - [PhoneComClient::ListGroups](docs/ListGroups.md)
 - [PhoneComClient::ListListeners](docs/ListListeners.md)
 - [PhoneComClient::ListMedia](docs/ListMedia.md)
 - [PhoneComClient::ListMenus](docs/ListMenus.md)
 - [PhoneComClient::ListOauthClients](docs/ListOauthClients.md)
 - [PhoneComClient::ListOauthClientsRedirectUris](docs/ListOauthClientsRedirectUris.md)
 - [PhoneComClient::ListPaymentMethods](docs/ListPaymentMethods.md)
 - [PhoneComClient::ListPhoneNumbers](docs/ListPhoneNumbers.md)
 - [PhoneComClient::ListPhoneNumbersRegions](docs/ListPhoneNumbersRegions.md)
 - [PhoneComClient::ListPricings](docs/ListPricings.md)
 - [PhoneComClient::ListQueues](docs/ListQueues.md)
 - [PhoneComClient::ListRoutes](docs/ListRoutes.md)
 - [PhoneComClient::ListSchedules](docs/ListSchedules.md)
 - [PhoneComClient::ListSms](docs/ListSms.md)
 - [PhoneComClient::ListTrunks](docs/ListTrunks.md)
 - [PhoneComClient::ListVoicemail](docs/ListVoicemail.md)
 - [PhoneComClient::ListenerFull](docs/ListenerFull.md)
 - [PhoneComClient::MediaFull](docs/MediaFull.md)
 - [PhoneComClient::MediaSummary](docs/MediaSummary.md)
 - [PhoneComClient::Member](docs/Member.md)
 - [PhoneComClient::MenuFull](docs/MenuFull.md)
 - [PhoneComClient::MenuSummary](docs/MenuSummary.md)
 - [PhoneComClient::Notification](docs/Notification.md)
 - [PhoneComClient::OauthAccessToken](docs/OauthAccessToken.md)
 - [PhoneComClient::OauthClientFull](docs/OauthClientFull.md)
 - [PhoneComClient::OauthClientRedirectUriFull](docs/OauthClientRedirectUriFull.md)
 - [PhoneComClient::Option](docs/Option.md)
 - [PhoneComClient::PatchPaymentParams](docs/PatchPaymentParams.md)
 - [PhoneComClient::PatchSmsParams](docs/PatchSmsParams.md)
 - [PhoneComClient::PatchVoicemailParams](docs/PatchVoicemailParams.md)
 - [PhoneComClient::PaymentFull](docs/PaymentFull.md)
 - [PhoneComClient::PaymentSummary](docs/PaymentSummary.md)
 - [PhoneComClient::PhoneNumberContact](docs/PhoneNumberContact.md)
 - [PhoneComClient::PhoneNumberFull](docs/PhoneNumberFull.md)
 - [PhoneComClient::PhoneNumbersRegionFull](docs/PhoneNumbersRegionFull.md)
 - [PhoneComClient::PingResponse](docs/PingResponse.md)
 - [PhoneComClient::PricingFull](docs/PricingFull.md)
 - [PhoneComClient::PricingObject](docs/PricingObject.md)
 - [PhoneComClient::QueueFull](docs/QueueFull.md)
 - [PhoneComClient::QueueSummary](docs/QueueSummary.md)
 - [PhoneComClient::Recipient](docs/Recipient.md)
 - [PhoneComClient::RedirectUriFull](docs/RedirectUriFull.md)
 - [PhoneComClient::ReplaceExtensionParams](docs/ReplaceExtensionParams.md)
 - [PhoneComClient::ReplaceMenuParams](docs/ReplaceMenuParams.md)
 - [PhoneComClient::ReplacePhoneNumberParams](docs/ReplacePhoneNumberParams.md)
 - [PhoneComClient::RouteFull](docs/RouteFull.md)
 - [PhoneComClient::RouteSummary](docs/RouteSummary.md)
 - [PhoneComClient::RuleSet](docs/RuleSet.md)
 - [PhoneComClient::RuleSetAction](docs/RuleSetAction.md)
 - [PhoneComClient::RuleSetFilter](docs/RuleSetFilter.md)
 - [PhoneComClient::RuleSetForwardItem](docs/RuleSetForwardItem.md)
 - [PhoneComClient::ScheduleFull](docs/ScheduleFull.md)
 - [PhoneComClient::ScheduleSummary](docs/ScheduleSummary.md)
 - [PhoneComClient::ScopeDetails](docs/ScopeDetails.md)
 - [PhoneComClient::SipAuthentication](docs/SipAuthentication.md)
 - [PhoneComClient::SmsForwarding](docs/SmsForwarding.md)
 - [PhoneComClient::SmsForwardingParams](docs/SmsForwardingParams.md)
 - [PhoneComClient::SmsFull](docs/SmsFull.md)
 - [PhoneComClient::SortCallLogs](docs/SortCallLogs.md)
 - [PhoneComClient::SortId](docs/SortId.md)
 - [PhoneComClient::SortIdCreatedAt](docs/SortIdCreatedAt.md)
 - [PhoneComClient::SortIdExtensionName](docs/SortIdExtensionName.md)
 - [PhoneComClient::SortIdName](docs/SortIdName.md)
 - [PhoneComClient::SortIdNamePhoneNumber](docs/SortIdNamePhoneNumber.md)
 - [PhoneComClient::SortIdUpdatedAt](docs/SortIdUpdatedAt.md)
 - [PhoneComClient::SortListAvailableNumbers](docs/SortListAvailableNumbers.md)
 - [PhoneComClient::SortListPhoneNumbersRegions](docs/SortListPhoneNumbersRegions.md)
 - [PhoneComClient::SortNameNumber](docs/SortNameNumber.md)
 - [PhoneComClient::TrunkFull](docs/TrunkFull.md)
 - [PhoneComClient::TrunkSummary](docs/TrunkSummary.md)
 - [PhoneComClient::Voicemail](docs/Voicemail.md)
 - [PhoneComClient::VoicemailFull](docs/VoicemailFull.md)
 - [PhoneComClient::VoicemailInput](docs/VoicemailInput.md)


## Documentation for Authorization


### apiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

